@@ -18,31 +18,35 @@ Entry::Entry(Feed *feed, int index)
     , m_feed(feed)
 {
     QSqlQuery entryQuery;
+    bool entryQueryPrepared = false;
     if (m_feed) {
-        entryQuery.prepare(QStringLiteral("SELECT * FROM Entries WHERE feed=:feed ORDER BY updated DESC LIMIT 1 OFFSET :index;"));
+        entryQueryPrepared = entryQuery.prepare(QStringLiteral("SELECT * FROM Entries WHERE feed=:feed ORDER BY updated DESC LIMIT 1 OFFSET :index;"));
         entryQuery.bindValue(QStringLiteral(":feed"), m_feed->url());
     } else {
-        entryQuery.prepare(QStringLiteral("SELECT * FROM Entries ORDER BY updated DESC LIMIT 1 OFFSET :index;"));
+        entryQueryPrepared = entryQuery.prepare(QStringLiteral("SELECT * FROM Entries ORDER BY updated DESC LIMIT 1 OFFSET :index;"));
     }
-    entryQuery.bindValue(QStringLiteral(":index"), index);
-    Database::instance().execute(entryQuery);
-    if (!entryQuery.next()) {
-        qWarning() << "No element with index" << index << "found";
-        if (m_feed) {
-            qDebug() << " in feed" << m_feed->url();
+    if (entryQueryPrepared) {
+        entryQuery.bindValue(QStringLiteral(":index"), index);
+        Database::instance().execute(entryQuery);
+        if (!entryQuery.next()) {
+            qWarning() << "No element with index" << index << "found";
+            if (m_feed) {
+                qDebug() << " in feed" << m_feed->url();
+            }
         }
     }
 
     QSqlQuery authorQuery;
-    authorQuery.prepare(QStringLiteral("SELECT * FROM Authors WHERE id=:id"));
-    authorQuery.bindValue(QStringLiteral(":id"), entryQuery.value(QStringLiteral("id")).toString());
-    Database::instance().execute(authorQuery);
+    if (authorQuery.prepare(QStringLiteral("SELECT * FROM Authors WHERE id=:id"))) {
+        authorQuery.bindValue(QStringLiteral(":id"), entryQuery.value(QStringLiteral("id")).toString());
+        Database::instance().execute(authorQuery);
 
-    while (authorQuery.next()) {
-        m_authors += new Author(authorQuery.value(QStringLiteral("name")).toString(),
-                                authorQuery.value(QStringLiteral("email")).toString(),
-                                authorQuery.value(QStringLiteral("uri")).toString(),
-                                nullptr);
+        while (authorQuery.next()) {
+            m_authors += new Author(authorQuery.value(QStringLiteral("name")).toString(),
+                                    authorQuery.value(QStringLiteral("email")).toString(),
+                                    authorQuery.value(QStringLiteral("uri")).toString(),
+                                    nullptr);
+        }
     }
 
     m_created.setSecsSinceEpoch(entryQuery.value(QStringLiteral("created")).toInt());
